pub fn evaluate_numeric(
rule_json: &str,
context_json: &str,
) -> RuleEngineResult<f64>Expand description
Evaluate a rule and coerce the result to f64.
pub fn evaluate_numeric(
rule_json: &str,
context_json: &str,
) -> RuleEngineResult<f64>Evaluate a rule and coerce the result to f64.